/**
 * Copyright 2008 Bluestem Software LLC.  All Rights Reserved.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 */

package org.bluestemsoftware.open.eoa.ext.idl.wsdl.wsdl20.xerces;

import java.util.ArrayList;
import java.util.List;

import javax.xml.namespace.QName;

import org.bluestemsoftware.open.eoa.commons.util.DOMUtils;
import org.bluestemsoftware.specification.eoa.component.RootComponent.ComponentName;
import org.bluestemsoftware.specification.eoa.ext.feature.ws.transport.http.HTTPMethod;
import org.bluestemsoftware.specification.eoa.ext.idl.wsdl.wsdl20.BindingOperationElement;
import org.bluestemsoftware.specification.eoa.ext.idl.wsdl.wsdl20.BindingOperationInfaultElement;
import org.bluestemsoftware.specification.eoa.ext.idl.wsdl.wsdl20.BindingOperationInputElement;
import org.bluestemsoftware.specification.eoa.ext.idl.wsdl.wsdl20.BindingOperationOutfaultElement;
import org.bluestemsoftware.specification.eoa.ext.idl.wsdl.wsdl20.BindingOperationOutputElement;
import org.bluestemsoftware.specification.eoa.ext.idl.wsdl.wsdl20.ExtendedDocument;
import org.bluestemsoftware.specification.eoa.ext.idl.wsdl.wsdl20.ext.HTTPBindingOperationElement;
import org.bluestemsoftware.specification.eoa.ext.idl.wsdl.wsdl20.ext.SOAPBindingOperationElement;
import org.w3c.dom.Element;

public class BindingOperationElementImpl extends AbstractWSDLElement implements BindingOperationElement, SOAPBindingOperationElement, HTTPBindingOperationElement {

    private static final long serialVersionUID = 1L;

    public BindingOperationElementImpl(WSDL20DocumentImpl owner) {
        super(owner, NAME.getNamespaceURI(), NAME.getPrefix() + ":" + NAME.getLocalPart());
    }

    public BindingOperationElementImpl() {
        super();
    }

    public void setRef(QName value) {
        if (value == null) {
            return;
        }
        String prefix = ((WSDL20DocumentImpl)getOwnerDocument()).addNamespace(value.getNamespaceURI());
        setAttribute("ref", prefix + ":" + value.getLocalPart());
    }

    public QName getRef() {
        String temp = getAttribute("ref");
        if (temp.equals("")) {
            return null;
        }
        return ComponentName.valueOf(this, temp);
    }

    public BindingOperationInputElement addInputElement(BindingOperationInputElement inputElement) {
        super.insertBefore(inputElement, null);
        return inputElement;
    }

    public List<BindingOperationInputElement> getInputElements() {
        List<Element> temp = DOMUtils.getChildElements(this, new QName(BindingOperationInputElement.NAME
                .getNamespaceURI(), BindingOperationInputElement.NAME.getLocalPart()));
        List<BindingOperationInputElement> answer = new ArrayList<BindingOperationInputElement>();
        for (Element element : temp) {
            answer.add((BindingOperationInputElement)element);
        }
        return answer;
    }

    public BindingOperationOutputElement addOutputElement(BindingOperationOutputElement outputElement) {
        super.insertBefore(outputElement, null);
        return outputElement;
    }

    public List<BindingOperationOutputElement> getOutputElements() {
        List<Element> temp = DOMUtils.getChildElements(this, new QName(BindingOperationOutputElement.NAME
                .getNamespaceURI(), BindingOperationOutputElement.NAME.getLocalPart()));
        List<BindingOperationOutputElement> answer = new ArrayList<BindingOperationOutputElement>();
        for (Element element : temp) {
            answer.add((BindingOperationOutputElement)element);
        }
        return answer;
    }

    public BindingOperationInfaultElement addInfaultElement(BindingOperationInfaultElement infaultElement) {
        super.insertBefore(infaultElement, null);
        return infaultElement;
    }

    public List<BindingOperationInfaultElement> getInfaultElements() {
        List<Element> temp = DOMUtils.getChildElements(this, new QName(BindingOperationInfaultElement.NAME
                .getNamespaceURI(), BindingOperationInfaultElement.NAME.getLocalPart()));
        List<BindingOperationInfaultElement> answer = new ArrayList<BindingOperationInfaultElement>();
        for (Element element : temp) {
            answer.add((BindingOperationInfaultElement)element);
        }
        return answer;
    }

    public BindingOperationOutfaultElement addOutfaultElement(BindingOperationOutfaultElement outfaultElement) {
        super.insertBefore(outfaultElement, null);
        return outfaultElement;
    }

    public List<BindingOperationOutfaultElement> getOutfaultElements() {
        List<Element> temp = DOMUtils.getChildElements(this, new QName(BindingOperationOutfaultElement.NAME
                .getNamespaceURI(), BindingOperationOutfaultElement.NAME.getLocalPart()));
        List<BindingOperationOutfaultElement> answer = new ArrayList<BindingOperationOutfaultElement>();
        for (Element element : temp) {
            answer.add((BindingOperationOutfaultElement)element);
        }
        return answer;
    }

    public void setMEP(String value) {
        setAttributeNS(ExtendedDocument.WSDL_SOAP_NS, ExtendedDocument.WSDL_SOAP_NS_PREFIX + ":mep", value);
    }

    public String getMEP() {
        return getAttributeNS(ExtendedDocument.WSDL_SOAP_NS, "mep").equals("") ? null : getAttributeNS(
                ExtendedDocument.WSDL_SOAP_NS, "mep");
    }

    public void setAction(String value) {
        setAttributeNS(ExtendedDocument.WSDL_SOAP_NS, ExtendedDocument.WSDL_SOAP_NS_PREFIX + ":action", value);
    }

    public String getAction() {
        return getAttributeNS(ExtendedDocument.WSDL_SOAP_NS, "action").equals("") ? null : getAttributeNS(
                ExtendedDocument.WSDL_SOAP_NS, "action");
    }

    public void setLocation(String value) {
        setAttributeNS(ExtendedDocument.WSDL_HTTP_NS, ExtendedDocument.WSDL_HTTP_NS_PREFIX + ":location", value);
    }

    public String getLocation() {
        return getAttributeNS(ExtendedDocument.WSDL_HTTP_NS, "location").equals("") ? null : getAttributeNS(
                ExtendedDocument.WSDL_HTTP_NS, "location");
    }

    public void setContentEncodingDefault(String value) {
        setAttributeNS(ExtendedDocument.WSDL_HTTP_NS, ExtendedDocument.WSDL_HTTP_NS_PREFIX
                + ":contentEncodingDefault", value);
    }

    public String getContentEncodingDefault() {
        return getAttributeNS(ExtendedDocument.WSDL_HTTP_NS, "contentEncodingDefault").equals("")
                ? null
                : getAttributeNS(ExtendedDocument.WSDL_HTTP_NS, "contentEncodingDefault");
    }

    public String getQueryParameterSeparator() {
        return getAttributeNS(ExtendedDocument.WSDL_HTTP_NS, "queryParameterSeparatorDefault").equals("")
                ? null
                : getAttributeNS(ExtendedDocument.WSDL_HTTP_NS, "queryParameterSeparatorDefault");
    }

    public Boolean ignoreUncited() {
        String temp = getAttributeNS(ExtendedDocument.WSDL_HTTP_NS, "ignoreUncited");
        if (temp.equals("")) {
            return null;
        }
        return Boolean.valueOf(temp);
    }

    public void setIgnoreUncited(Boolean value) {
        if (value != null) {
            setAttributeNS(ExtendedDocument.WSDL_HTTP_NS, ExtendedDocument.WSDL_HTTP_NS_PREFIX + ":ignoreUncited",
                    value.toString());
        }
    }

    public void setQueryParameterSeparator(String value) {
        if (value != null) {
            setAttributeNS(ExtendedDocument.WSDL_HTTP_NS, ExtendedDocument.WSDL_HTTP_NS_PREFIX
                    + ":queryParameterSeparatorDefault", value.toString());
        }
    }

    public String getFaultSerialization() {
        return getAttributeNS(ExtendedDocument.WSDL_HTTP_NS, "faultSerialization").equals("")
                ? null
                : getAttributeNS(ExtendedDocument.WSDL_HTTP_NS, "faultSerialization");
    }

    public String getInputSerialization() {
        return getAttributeNS(ExtendedDocument.WSDL_HTTP_NS, "inputSerialization").equals("")
                ? null
                : getAttributeNS(ExtendedDocument.WSDL_HTTP_NS, "inputSerialization");
    }

    public HTTPMethod getMethod() {
        String temp = getAttributeNS(ExtendedDocument.WSDL_HTTP_NS, "method");
        if (temp.equals("")) {
            return null;
        } else {
            return HTTPMethod.valueOf(temp);
        }
    }

    public String getOutputSerialization() {
        return getAttributeNS(ExtendedDocument.WSDL_HTTP_NS, "outputSerialization").equals("")
                ? null
                : getAttributeNS(ExtendedDocument.WSDL_HTTP_NS, "outputSerialization");
    }

    public void setFaultSerialization(String value) {
        if (value != null) {
            setAttributeNS(ExtendedDocument.WSDL_HTTP_NS, ExtendedDocument.WSDL_HTTP_NS_PREFIX
                    + ":faultSerialization", value.toString());
        }
    }

    public void setInputSerialization(String value) {
        if (value != null) {
            setAttributeNS(ExtendedDocument.WSDL_HTTP_NS, ExtendedDocument.WSDL_HTTP_NS_PREFIX
                    + ":inputSerialization", value.toString());
        }
    }

    public void setMethod(HTTPMethod value) {
        if (value != null) {
            setAttributeNS(ExtendedDocument.WSDL_HTTP_NS, ExtendedDocument.WSDL_HTTP_NS_PREFIX + ":method", value
                    .toString());
        }
    }

    public void setOutputSerialization(String value) {
        if (value != null) {
            setAttributeNS(ExtendedDocument.WSDL_HTTP_NS, ExtendedDocument.WSDL_HTTP_NS_PREFIX
                    + ":outputSerialization", value.toString());
        }
    }

}
